@@ -47,7 +47,6 @@ class GoogleCalendarInterface:
     max_retries = 5
     auth_http = None
     cal_service = None
-    url_service = None
 
     ACCESS_OWNER = 'owner'
     ACCESS_WRITER = 'writer'
@@ -140,8 +139,7 @@ class GoogleCalendarInterface:
                     OAuth2WebServerFlow(
                         client_id=self.options['client_id'],
                         client_secret=self.options['client_secret'],
-                        scope=['https://www.googleapis.com/auth/calendar',
-                               'https://www.googleapis.com/auth/urlshortener'],
+                        scope=['https://www.googleapis.com/auth/calendar'],
                         user_agent=__program__ + '/' + __version__
                     ),
                     storage,
@@ -160,15 +158,6 @@ class GoogleCalendarInterface:
 
         return self.cal_service
 
-    def get_url_service(self):
-        if not self.url_service:
-            self._google_auth()
-            self.url_service = build(serviceName='urlshortener',
-                                     version='v1',
-                                     http=self._google_auth())
-
-        return self.url_service
-
     def _get_cached(self):
         if self.options['config_folder']:
             cache_file = os.path.expanduser(
@@ -224,16 +213,6 @@ class GoogleCalendarInterface:
             with open(cache_file, 'wb') as _cache_:
                 pickle.dump(self.cache, _cache_)
 
-    def _shorten_url(self, url):
-        if self.details.get('url', False) != 'short':
-            return url
-        # Note that when authenticated to a google account different shortUrls
-        # can be returned for the same longUrl. See: http://goo.gl/Ya0A9
-        shortUrl = self._retry_with_backoff(
-                self.get_url_service().url().insert(body={'longUrl': url})
-        )
-        return shortUrl['id']
-
     def _calendar_color(self, event, override_color=False):
         ansi_codes = {
             '1': 'brightblue',
@@ -317,6 +296,7 @@ class GoogleCalendarInterface:
         week_events = [[] for _ in range(7)]
 
         now_in_week = True
+        now_marker_printed = False
         if self.now < start_dt or self.now > end_dt:
             now_in_week = False
 
@@ -344,28 +324,18 @@ class GoogleCalendarInterface:
             # events which was started before current period of time and are
             # still continue in current period of time
             if event_is_today or (event_allday and event_continues_today):
-                force_now_marker = False
+                color_as_now_marker = False
 
-                if now_in_week:
+                if now_in_week and not now_marker_printed:
                     if (days_since_epoch(self.now) <
                             days_since_epoch(event['s'])):
-                        force_now_marker = False
-                        week_events[event_daynum - 1].append(
-                                EventTitle(
-                                    '\n' + self.options['cal_width'] * '-',
-                                    self.options['color_now_marker']
-                                )
-                        )
-
-                    elif self.now <= event['s']:
-                        # add a line marker before next event
-                        force_now_marker = False
                         week_events[event_daynum].append(
                                 EventTitle(
                                     '\n' + self.options['cal_width'] * '-',
                                     self.options['color_now_marker']
                                 )
                         )
+                        now_marker_printed = True
 
                     # We don't want to recolor all day events, but ignoring
                     # them leads to issues where the 'now' marker misprints
@@ -376,9 +346,10 @@ class GoogleCalendarInterface:
                             self.now <= event_end_date and \
                             not event_allday:
                         # line marker is during the event (recolor event)
-                        force_now_marker = True
+                        color_as_now_marker = True
+                        now_marker_printed = True
 
-                if force_now_marker:
+                if color_as_now_marker:
                     event_color = self.options['color_now_marker']
                 else:
                     if self.options['override_color'] and event.get('colorId'):
@@ -429,20 +400,25 @@ class GoogleCalendarInterface:
             if stop >= self.options['cal_width']:
                 return stop, i + 1
 
-    def _next_cut(self, string, cur_print_len):
+    def _next_cut(self, string):
         print_len = 0
 
         words = _u(string).split()
+        word_lens = []
         for i, word in enumerate(words):
-            word_len = self._printed_len(word)
-            if (cur_print_len + word_len + print_len) >= \
-                    self.options['cal_width']:
+            word_lens.append(self._printed_len(word))
+
+            if (word_lens[-1] + print_len) >= self.options['cal_width']:
+                # this many words is too many, try to cut at the prev word
                 cut_idx = len(' '.join(words[:i]))
-                # if the first word is too long, we cannot cut between words
+
+                # first word is too long, we must cut inside it
                 if cut_idx == 0:
                     return self._word_cut(word)
+
                 return (print_len, cut_idx)
-            print_len += word_len + i  # +i for the space between words
+            print_len = sum(word_lens) + i  # +i for the space between words
+
         return (print_len, len(' '.join(words[:i])))
 
     def _get_cut_index(self, event_string):
@@ -459,7 +435,7 @@ class GoogleCalendarInterface:
 
         else:
             # we must cut: _next_cut will loop until we find the right spot
-            return self._next_cut(event_string, 0)
+            return self._next_cut(event_string)
 
     def _GraphEvents(self, cmd, start_datetime, count, event_list):
         # ignore started events (i.e. events that start previous day and end
@@ -621,9 +597,9 @@ class GoogleCalendarInterface:
                                          _u(event['e'].strftime('%H:%M')))
 
             if self.details.get('url'):
-                output += '\t%s' % (self._shorten_url(event['htmlLink'])
+                output += '\t%s' % (event['htmlLink']
                                     if 'htmlLink' in event else '')
-                output += '\t%s' % (self._shorten_url(event['hangoutLink'])
+                output += '\t%s' % (event['hangoutLink']
                                     if 'hangoutLink' in event else '')
 
             output += '\t%s' % _u(self._valid_title(event).strip())
@@ -724,12 +700,12 @@ class GoogleCalendarInterface:
             self.printer.msg(xstr, 'default')
 
         if self.details.get('url') and 'htmlLink' in event:
-            hlink = self._shorten_url(event['htmlLink'])
+            hlink = event['htmlLink']
             xstr = '%s  Link: %s\n' % (details_indent, hlink)
             self.printer.msg(xstr, 'default')
 
         if self.details.get('url') and 'hangoutLink' in event:
-            hlink = self._shorten_url(event['hangoutLink'])
+            hlink = event['hangoutLink']
             xstr = '%s  Hangout Link: %s\n' % (details_indent, hlink)
             self.printer.msg(xstr, 'default')
 
@@ -1282,7 +1258,7 @@ class GoogleCalendarInterface:
                         )
 
         if self.details.get('url'):
-            hlink = self._shorten_url(new_event['htmlLink'])
+            hlink = new_event['htmlLink']
             self.printer.msg('New event added: %s\n' % hlink, 'green')
 
         return new_event
@@ -1323,7 +1299,7 @@ class GoogleCalendarInterface:
         new_event = self._retry_with_backoff(request)
 
         if self.details.get('url'):
-            hlink = self._shorten_url(new_event['htmlLink'])
+            hlink = new_event['htmlLink']
             self.printer.msg('New event added: %s\n' % hlink, 'green')
 
         return new_event
@@ -1557,7 +1533,7 @@ class GoogleCalendarInterface:
                                             body=event
                                         )
                                 )
-                    hlink = self._shorten_url(new_event.get('htmlLink'))
+                    hlink = new_event.get('htmlLink')
                     self.printer.msg(
                             'New event added: %s\n' % hlink, 'green'
                     )
@@ -1576,7 +1552,7 @@ class GoogleCalendarInterface:
                                             body=event
                                         )
                                 )
-                    hlink = self._shorten_url(new_event.get('htmlLink'))
+                    hlink = new_event.get('htmlLink')
                     self.printer.msg('New event added: %s\n' % hlink, 'green')
                 elif val.lower() == 'q':
                     sys.exit(0)
